/*
 Copyright (c) 2001-2004, Kurt Revis.  All rights reserved.

 This source code is licensed under the BSD-style license found in the
 LICENSE file in the root directory of this source tree.
 */

#include <SnoizeMIDISpy/MIDISpyClient.h>
#include <SnoizeMIDISpy/MIDISpyDriverInstallation.h>
